scripts/install-debugclients.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8043
0acf98cd089a
child 8243
cc717c2ae956
diff -r 44e15eda6506 -r e8fc383322f7 scripts/install-debugclients.py
--- a/scripts/install-debugclients.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/scripts/install-debugclients.py	Wed Jan 06 13:47:01 2021 +0100
@@ -3,12 +3,12 @@
 
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for the eric6 debug client. It may be used
 # to just install the debug clients for remote debugging.
 #
 
 """
-Installation script for the eric6 debug clients.
+Installation script for the eric debug clients.
 """
 
 import io
@@ -69,7 +69,7 @@
         print("    {0} [-chz][-d dir] [-i dir]".format(progName))
     print("where:")
     print("    -h, --help display this help message")
-    print("    -d dir     where eric6 debug client files will be installed")
+    print("    -d dir     where eric debug client files will be installed")
     print("               (default: {0})".format(modDir))
     if not sys.platform.startswith("win"):
         print("    -i dir     temporary install prefix")
@@ -210,7 +210,7 @@
     
     try:
         # Install the files
         # copy the various parts of eric6 debug clients
         copyTree(
             os.path.join(eric6SourceDir, "DebugClients"), targetDir,
             ['*.py', '*.pyc', '*.pyo', '*.pyw'],
@@ -241,7 +241,7 @@
     global sourceDir
     
     if sys.version_info < (3, 6, 0) or sys.version_info >= (4, 0, 0):
-        print('Sorry, the eric6 debugger requires Python 3.6 or better'
+        print('Sorry, the eric debugger requires Python 3.6 or better'
               ' for running.')
         exit(5)
     
@@ -318,7 +318,7 @@
                 rx=skipRe,
                 quiet=True)
         sys.stdout = sys.__stdout__
-    print("\nInstalling eric6 debug clients ...")
+    print("\nInstalling eric debug clients ...")
     res = installEricDebugClients()
     
     print("\nInstallation complete.")
@@ -3,12 +3,12 @@
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for the eric6 debug client. It may be used
+# This is the install script for the eric debug client. It may be used
 # to just install the debug clients for remote debugging.
 #
@@ -210,7 +210,7 @@
     try:
         # Install the files
-        # copy the various parts of eric6 debug clients
+        # copy the various parts of eric debug clients
         copyTree(
             os.path.join(eric6SourceDir, "DebugClients"), targetDir,

eric ide

mercurial